summaryrefslogtreecommitdiffstats
path: root/src/gallium/drivers/radeon/MCTargetDesc
diff options
context:
space:
mode:
authorTom Stellard <[email protected]>2012-08-23 19:28:50 +0000
committerTom Stellard <[email protected]>2012-08-23 21:54:32 +0000
commit228a6641ccddaf24a993f827af1e97379785985a (patch)
treec9ff0fd8f4a53f42ffce6377ddf7d06165311fb3 /src/gallium/drivers/radeon/MCTargetDesc
parent5a1edb8655aeab17bf0d90e202fb31a1adb53498 (diff)
radeon/llvm: Pull changes from external version of the backend
Diffstat (limited to 'src/gallium/drivers/radeon/MCTargetDesc')
-rw-r--r--src/gallium/drivers/radeon/MCTargetDesc/AMDGPUAsmBackend.cpp2
-rw-r--r--src/gallium/drivers/radeon/MCTargetDesc/AMDGPUMCAsmInfo.cpp (renamed from src/gallium/drivers/radeon/MCTargetDesc/AMDILMCAsmInfo.cpp)10
-rw-r--r--src/gallium/drivers/radeon/MCTargetDesc/AMDGPUMCAsmInfo.h (renamed from src/gallium/drivers/radeon/MCTargetDesc/AMDILMCAsmInfo.h)12
-rw-r--r--src/gallium/drivers/radeon/MCTargetDesc/AMDGPUMCTargetDesc.cpp (renamed from src/gallium/drivers/radeon/MCTargetDesc/AMDILMCTargetDesc.cpp)6
-rw-r--r--src/gallium/drivers/radeon/MCTargetDesc/AMDGPUMCTargetDesc.h (renamed from src/gallium/drivers/radeon/MCTargetDesc/AMDILMCTargetDesc.h)10
-rw-r--r--src/gallium/drivers/radeon/MCTargetDesc/R600MCCodeEmitter.cpp2
-rw-r--r--src/gallium/drivers/radeon/MCTargetDesc/SIMCCodeEmitter.cpp2
7 files changed, 22 insertions, 22 deletions
diff --git a/src/gallium/drivers/radeon/MCTargetDesc/AMDGPUAsmBackend.cpp b/src/gallium/drivers/radeon/MCTargetDesc/AMDGPUAsmBackend.cpp
index 10bf5a39366..5b31bc6c8f0 100644
--- a/src/gallium/drivers/radeon/MCTargetDesc/AMDGPUAsmBackend.cpp
+++ b/src/gallium/drivers/radeon/MCTargetDesc/AMDGPUAsmBackend.cpp
@@ -7,7 +7,7 @@
//
//===----------------------------------------------------------------------===//
-#include "MCTargetDesc/AMDILMCTargetDesc.h"
+#include "MCTargetDesc/AMDGPUMCTargetDesc.h"
#include "llvm/ADT/StringRef.h"
#include "llvm/MC/MCAsmBackend.h"
#include "llvm/MC/MCAssembler.h"
diff --git a/src/gallium/drivers/radeon/MCTargetDesc/AMDILMCTargetDesc.cpp b/src/gallium/drivers/radeon/MCTargetDesc/AMDGPUMCTargetDesc.cpp
index bb447359a7a..523b4da506a 100644
--- a/src/gallium/drivers/radeon/MCTargetDesc/AMDILMCTargetDesc.cpp
+++ b/src/gallium/drivers/radeon/MCTargetDesc/AMDGPUMCTargetDesc.cpp
@@ -1,5 +1,5 @@
-#include "AMDILMCTargetDesc.h"
-#include "AMDILMCAsmInfo.h"
+#include "AMDGPUMCTargetDesc.h"
+#include "AMDGPUMCAsmInfo.h"
#include "InstPrinter/AMDGPUInstPrinter.h"
#include "llvm/MC/MachineLocation.h"
#include "llvm/MC/MCCodeGenInfo.h"
@@ -78,7 +78,7 @@ static MCStreamer *createMCStreamer(const Target &T, StringRef TT,
extern "C" void LLVMInitializeAMDGPUTargetMC() {
- RegisterMCAsmInfo<AMDILMCAsmInfo> Y(TheAMDGPUTarget);
+ RegisterMCAsmInfo<AMDGPUMCAsmInfo> Y(TheAMDGPUTarget);
TargetRegistry::RegisterMCCodeGenInfo(TheAMDGPUTarget, createAMDGPUMCCodeGenInfo);
diff --git a/src/gallium/drivers/radeon/MCTargetDesc/AMDILMCTargetDesc.h b/src/gallium/drivers/radeon/MCTargetDesc/AMDGPUMCTargetDesc.h
index 3ff5daf8b61..328e367401a 100644
--- a/src/gallium/drivers/radeon/MCTargetDesc/AMDILMCTargetDesc.h
+++ b/src/gallium/drivers/radeon/MCTargetDesc/AMDGPUMCTargetDesc.h
@@ -1,4 +1,4 @@
-//===-- AMDILMCTargetDesc.h - AMDIL Target Descriptions -----*- C++ -*-===//
+//===-- AMDGPUMCTargetDesc.h - AMDGPU Target Descriptions -----*- C++ -*-===//
//
// The LLVM Compiler Infrastructure
//
@@ -7,13 +7,13 @@
//
//===----------------------------------------------------------------------===//
//
-// This file provides AMDIL specific target descriptions.
+// This file provides AMDGPU specific target descriptions.
//
//===----------------------------------------------------------------------===//
//
-#ifndef AMDILMCTARGETDESC_H
-#define AMDILMCTARGETDESC_H
+#ifndef AMDGPUMCTARGETDESC_H
+#define AMDGPUMCTARGETDESC_H
#include "llvm/ADT/StringRef.h"
@@ -48,4 +48,4 @@ MCAsmBackend *createAMDGPUAsmBackend(const Target &T, StringRef TT);
#define GET_SUBTARGETINFO_ENUM
#include "AMDGPUGenSubtargetInfo.inc"
-#endif // AMDILMCTARGETDESC_H
+#endif // AMDGPUMCTARGETDESC_H
diff --git a/src/gallium/drivers/radeon/MCTargetDesc/R600MCCodeEmitter.cpp b/src/gallium/drivers/radeon/MCTargetDesc/R600MCCodeEmitter.cpp
index 99db28be3ab..46360e3ccbd 100644
--- a/src/gallium/drivers/radeon/MCTargetDesc/R600MCCodeEmitter.cpp
+++ b/src/gallium/drivers/radeon/MCTargetDesc/R600MCCodeEmitter.cpp
@@ -17,7 +17,7 @@
//===----------------------------------------------------------------------===//
#include "R600Defines.h"
-#include "MCTargetDesc/AMDILMCTargetDesc.h"
+#include "MCTargetDesc/AMDGPUMCTargetDesc.h"
#include "MCTargetDesc/AMDGPUMCCodeEmitter.h"
#include "llvm/MC/MCCodeEmitter.h"
#include "llvm/MC/MCContext.h"
diff --git a/src/gallium/drivers/radeon/MCTargetDesc/SIMCCodeEmitter.cpp b/src/gallium/drivers/radeon/MCTargetDesc/SIMCCodeEmitter.cpp
index 3d923055a59..481e65bf7af 100644
--- a/src/gallium/drivers/radeon/MCTargetDesc/SIMCCodeEmitter.cpp
+++ b/src/gallium/drivers/radeon/MCTargetDesc/SIMCCodeEmitter.cpp
@@ -12,7 +12,7 @@
//
//===----------------------------------------------------------------------===//
-#include "MCTargetDesc/AMDILMCTargetDesc.h"
+#include "MCTargetDesc/AMDGPUMCTargetDesc.h"
#include "MCTargetDesc/AMDGPUMCCodeEmitter.h"
#include "llvm/MC/MCCodeEmitter.h"
#include "llvm/MC/MCContext.h"
diff --git a/src/gallium/drivers/radeon/MCTargetDesc/AMDILMCAsmInfo.cpp b/src/gallium/drivers/radeon/MCTargetDesc/AMDGPUMCAsmInfo.cpp
index 1f3e4e7c0d4..4fdd4835ed7 100644
--- a/src/gallium/drivers/radeon/MCTargetDesc/AMDILMCAsmInfo.cpp
+++ b/src/gallium/drivers/radeon/MCTargetDesc/AMDGPUMCAsmInfo.cpp
@@ -1,4 +1,4 @@
//===-- MCTargetDesc/AMDILMCAsmInfo.cpp - TODO: Add brief description -------===//
//
// The LLVM Compiler Infrastructure
//
@@ -11,13 +11,13 @@
//
//===----------------------------------------------------------------------===//
-#include "AMDILMCAsmInfo.h"
+#include "AMDGPUMCAsmInfo.h"
#ifndef NULL
#define NULL 0
#endif
using namespace llvm;
-AMDILMCAsmInfo::AMDILMCAsmInfo(const Target &T, StringRef &TT) : MCAsmInfo()
+AMDGPUMCAsmInfo::AMDGPUMCAsmInfo(const Target &T, StringRef &TT) : MCAsmInfo()
{
HasSingleParameterDotFile = false;
WeakDefDirective = NULL;
@@ -85,7 +85,7 @@ AMDILMCAsmInfo::AMDILMCAsmInfo(const Target &T, StringRef &TT) : MCAsmInfo()
AsmTransCBE = NULL;
}
const char*
-AMDILMCAsmInfo::getDataASDirective(unsigned int Size, unsigned int AS) const
+AMDGPUMCAsmInfo::getDataASDirective(unsigned int Size, unsigned int AS) const
{
switch (AS) {
default:
@@ -97,7 +97,7 @@ AMDILMCAsmInfo::getDataASDirective(unsigned int Size, unsigned int AS) const
}
const MCSection*
-AMDILMCAsmInfo::getNonexecutableStackSection(MCContext &CTX) const
+AMDGPUMCAsmInfo::getNonexecutableStackSection(MCContext &CTX) const
{
return NULL;
}
@@ -1,4 +1,4 @@
-//===-- MCTargetDesc/AMDILMCAsmInfo.cpp - TODO: Add brief description -------===//
+//===-- MCTargetDesc/AMDGPUMCAsmInfo.cpp - TODO: Add brief description -------===//
//
// The LLVM Compiler Infrastructure
diff --git a/src/gallium/drivers/radeon/MCTargetDesc/AMDILMCAsmInfo.h b/src/gallium/drivers/radeon/MCTargetDesc/AMDGPUMCAsmInfo.h
index d354b03351c..0ca264beb0f 100644
--- a/src/gallium/drivers/radeon/MCTargetDesc/AMDILMCAsmInfo.h
+++ b/src/gallium/drivers/radeon/MCTargetDesc/AMDGPUMCAsmInfo.h
@@ -1,4 +1,4 @@
//===-- MCTargetDesc/AMDILMCAsmInfo.h - TODO: Add brief description -------===//
//
// The LLVM Compiler Infrastructure
//
@@ -11,20 +11,20 @@
//
//===----------------------------------------------------------------------===//
-#ifndef AMDILMCASMINFO_H_
-#define AMDILMCASMINFO_H_
+#ifndef AMDGPUMCASMINFO_H_
+#define AMDGPUMCASMINFO_H_
#include "llvm/MC/MCAsmInfo.h"
namespace llvm {
class Target;
class StringRef;
- class AMDILMCAsmInfo : public MCAsmInfo {
+ class AMDGPUMCAsmInfo : public MCAsmInfo {
public:
- explicit AMDILMCAsmInfo(const Target &T, StringRef &TT);
+ explicit AMDGPUMCAsmInfo(const Target &T, StringRef &TT);
const char*
getDataASDirective(unsigned int Size, unsigned int AS) const;
const MCSection* getNonexecutableStackSection(MCContext &CTX) const;
};
} // namespace llvm
-#endif // AMDILMCASMINFO_H_
+#endif // AMDGPUMCASMINFO_H_
@@ -1,4 +1,4 @@
-//===-- MCTargetDesc/AMDILMCAsmInfo.h - TODO: Add brief description -------===//
+//===-- MCTargetDesc/AMDGPUMCAsmInfo.h - TODO: Add brief description -------===//
//
// The LLVM Compiler Infrastructure